Skip to contents

Explicitly marks a string as a text label (not a data variable name). Useful when a label string might coincidentally match a column name.

Usage

label(x)

Arguments

x

Character string to use as a label

Value

A tplyr_label object