label.Rd
Explicitly marks a string as a text label (not a data variable name). Useful when a label string might coincidentally match a column name.
label(x)
Character string to use as a label
A tplyr_label object