total_group.Rd
Specifies that a synthetic "Total" column level should be added by duplicating all rows with the specified column variable set to the label.
total_group(col_var, label = "Total")
Character string naming the column variable to totalize
Character string for the total group label (default: "Total")
A tplyr_total_group object