Skip to contents

Returns the population-based header N values that were computed during tplyr_build(). Only available when population data was provided.

Usage

tplyr_header_n(result)

Arguments

result

A data.frame produced by tplyr_build()

Value

A data.frame with column variable levels and their N values, or NULL if no population data was used.