Get source data rows for a specific output cell
tplyr_meta_subset.RdEvaluates the stored filter expressions against the original data to return the rows that contributed to the specified output cell.
Arguments
- result
A data.frame from
tplyr_build()built withmetadata = TRUE- row_id
Character row ID
- column
Character column name (e.g.,
"res1")- data
The original data.frame that was passed to
tplyr_build()- pop_data
Optional population data.frame, required when the cell represents a missing subjects row (anti-join)