Retrieve raw numeric data from a tplyr_build result
tplyr_numeric_data.RdReturns the unformatted numeric data that was computed during the build process, before formatting and pivoting to wide format.
Arguments
- result
A data.frame produced by
tplyr_build()- layer
Integer layer index (1-based), or NULL for all layers