Retrieve raw statistic values from a tplyr_build result
tplyr_stats_data.RdFilters the raw numeric data for a specific layer and statistic.
Arguments
- result
A data.frame produced by
tplyr_build()- layer
Integer layer index (1-based)
- statistic
Character string naming the statistic column to extract (e.g., "n", "pct", "mean", "sd")